# This processes a export plot of Genesis table 62361-0501
# (cf. https://www-genesis.destatis.de/).  OMG

import contextlib
import csv
import pprint
import re

from matplotlib import pyplot

@contextlib.contextmanager
def fig_writeto(dest_name, **kwargs):
	"""starts a new pyplot figure and saves it to dest_name once
	the controlled section is left.
	"""
	fig = pyplot.figure(**kwargs)
	ax = fig.add_subplot(111)
	yield ax

	if dest_name is None:
		pyplot.show()
	else:
		fig.savefig(dest_name, dpi=200)


def main():
	with open("62361-0501.csv") as f:
		table = list(csv.reader(f, delimiter=";"))

	# nuke the odd headers and the sub-categories, marked by numeric codes
	# in col. 2
	subcat_pat = re.compile(".*-\d+$")
	table = [row for row in table[8:] if not subcat_pat.match(row[1])]

	# project out category and tarifbindung
	table = [[row[2], float(row[3])] for row in table]
	
	# add the value from https://www.deutschlandfunk.de/hintergrund-100.html?drsearch:date=2023-05-30
	table.append(["Leiharbeit", 98])
	table.sort(key=lambda r: r[1])
	
	with fig_writeto("tarifbindung-vs-branche.png",
			figsize=(4,5), tight_layout=True) as ax:
		ax.set_title("Tarifbindung nach Branche, in Prozent")
		barpos = list(range(len(table)))
		ax.barh(barpos, [row[1] for row in table], color="#aabbcc")
		ax.tick_params('both', length=0, width=0)
		ax.set_yticks(barpos)
		ax.set_yticklabels(
			[row[0] for row in table],
			fontdict={'horizontalalignment': 'left', 'fontsize': 8},
			x=0.05)
		ax.grid(True, axis='x')
		ax.set_frame_on(False)

main()
